import pyautogui as pg
import random
from datetime import datetime
from time import sleep
import os

offset = 10
pg.PAUSE = 2.5
pg.FAILSAFE = False
screenWidth, screenHeight = pg.size()


def run():
    print("Hilale: Keeps the mouse running...")

    try:
        while True:
            rand_width = random.randint(offset, screenWidth - offset)
            rand_height = random.randint(offset, screenHeight - offset)
            pg.moveTo(rand_width, rand_height, 2, pg.easeInElastic)
            print((rand_width, rand_height))
            now = datetime.now()
            if now.minute % 5 == 0:
                print("Mouse Click & Sleep")
                pg.click(screenWidth / 2, screenHeight / 2)
                sleep(30)
    except KeyboardInterrupt:
        print("Over!!!\n")

    os.system("pause")



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['hilale']

package_data = \
{'': ['*']}

install_requires = \
['pyautogui>=0.9.48,<0.10.0']

setup_kwargs = {
    'name': 'hilale',
    'version': '0.1.2',
    'description': 'A simple python utility to keep the mouse moving on the screen',
    'long_description': '# Hilale\n\nA python utility to keep the mouse moving and keep the system from getting locked.\n\n## Install\n\n```bash\npip install hilale\n```\n\n## Use\n\n```bash\npython -m hilale\n```\n',
    'author': 'rkshrksh',
    'author_email': 'aarkaygautam@gmail.com',
    'url': 'https://github.com/rkshrksh/Hilale',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
